package com.usky.issue.service.impl;

import com.baomidou.dynamic.datasource.annotation.DS;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.issue.domain.SpOwner;
import com.usky.issue.mapper.SpOwnerMapper;
import com.usky.issue.service.SpOwnerService;
import com.usky.common.mybatis.core.AbstractCrudService;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author fu
 * @since 2024-01-04
 */
@Service
@DS("jdxf")
public class SpOwnerServiceImpl extends AbstractCrudService<SpOwnerMapper, SpOwner> implements SpOwnerService {

    /**
     * 获取所有设备编号
     * @return
     */
    @Override
    public List<String> getDeviceCodes() {
        List<String> owner_company = Arrays.asList("10327", "10331", "10334");
        LambdaQueryWrapper<SpOwner> device = Wrappers.lambdaQuery();
        device.select(SpOwner::getOwnerCode)
                .in(SpOwner::getCompany,owner_company);

        return baseMapper.selectObjs(device)
                .stream()
                .map(String::valueOf)
                .collect(Collectors.toList());
    }

    /**
     * 校区
     * @return
     */
    public String getCampus(String company) {
        if (company.contains("10327")) {
            return "西校区";
        } else if (company.contains("10331")) {
            return "东校区";
        } else {
            return "中山南一路院区";
        }
    }

    /**
     * 获取所有设备信息
     * @return
     */
    @Override
    public List<SpOwner> getOwners(List<String> deviceCode) {
        LambdaQueryWrapper<SpOwner> device1 = Wrappers.lambdaQuery();
        device1.select(SpOwner::getId,SpOwner::getCompany,SpOwner::getOwnerCode,SpOwner::getOwnerName,
                SpOwner::getUnitinfo,SpOwner::getLouyu,SpOwner::getInstallTime,SpOwner::getDwtype)
                .in(SpOwner::getOwnerCode,getDeviceCodes());
        return baseMapper.selectList(device1);
    }

    /**
     * 获取类型
     * @param deviceCode
     * @return
     */
    @Override
    public Integer getType(String deviceCode) {
        LambdaQueryWrapper<SpOwner> tpye = Wrappers.lambdaQuery();
        tpye.select(SpOwner::getDwtype)
                .in(SpOwner::getOwnerCode,deviceCode);
        return baseMapper.selectOne(tpye).getDwtype();
    }

    @Override
    public List<SpOwner> getOwnersAfter(Integer lastId) {
        LambdaQueryWrapper<SpOwner> wrapper = Wrappers.lambdaQuery();
        wrapper.select(SpOwner::getId,SpOwner::getOwnerName,SpOwner::getInstallTime,SpOwner::getUnitinfo,
                SpOwner::getLouyu,SpOwner::getDwtype,SpOwner::getCompany,SpOwner::getOwnerCode)
                .gt(SpOwner::getId,lastId)
                .in(SpOwner::getOwnerCode,getDeviceCodes());
        return baseMapper.selectList(wrapper);
    }
}
